package edu.sc.seis.darkMagic;

import java.util.Properties;

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.SimpleLayout;

import edu.iris.Fissures.Time;
import edu.iris.Fissures.IfNetwork.Channel;
import edu.iris.Fissures.IfNetwork.ChannelId;
import edu.iris.Fissures.IfNetwork.NetworkAccess;
import edu.iris.Fissures.IfNetwork.NetworkDCOperations;
import edu.iris.Fissures.IfNetwork.NetworkFinder;
import edu.iris.Fissures.IfNetwork.NetworkId;
import edu.iris.Fissures.IfNetwork.Station;
import edu.iris.Fissures.IfSeismogramDC.DataCenter;
import edu.iris.Fissures.IfSeismogramDC.LocalSeismogram;
import edu.iris.Fissures.IfSeismogramDC.RequestFilter;
import edu.iris.Fissures.model.AllVTFactory;
import edu.iris.Fissures.model.MicroSecondDate;
import edu.iris.Fissures.model.TimeInterval;
import edu.iris.Fissures.model.UnitImpl;
import edu.iris.Fissures.network.NetworkIdUtil;
import edu.sc.seis.fissuresUtil.namingService.FissuresNamingService;
import edu.sc.seis.fissuresUtil.simple.Initializer;

/**
 * @author crotwell Created on Feb 10, 2005
 */
public class Client {

    public static void main(String[] args) throws Exception {
        Initializer.init(args);
        BasicConfigurator.configure(new ConsoleAppender(new SimpleLayout()));
        Properties props = Initializer.getProps();
        System.getProperties().putAll(props);
        logger.info("loaded props: darkMagic.passwordFile="+Initializer.getProps().getProperty("darkMagic.passwordFile")+"  sys="+System.getProperty("darkMagic.passwordFile"));
        // Initialize the ORB. This must be done before the corba system can be
        // used.
        org.omg.CORBA_2_3.ORB orb = (org.omg.CORBA_2_3.ORB)org.omg.CORBA.ORB.init(new String[] {},
                                                                                  props);
        // Registers the FISSURES classes with the ORB
        new AllVTFactory().register(orb);
        // Pick a name server to get FISSURES servers.
        FissuresNamingService namingService = new FissuresNamingService(orb);
//        namingService.setNameServiceCorbaLoc("corbaloc:iiop:dmc.iris.washington.edu:6371/NameService");
        namingService.setNameServiceCorbaLoc("corbaloc:iiop:nameservice.seis.sc.edu:6371/NameService");
        NetworkDCOperations netDC = namingService.getNetworkDC("edu/iris/dmc",
                                                               "IRIS_NetworkDC");
        NetworkFinder netFinder = netDC.a_finder();
        NetworkAccess[] nets = netFinder.retrieve_by_code("XY");
        NetworkAccess net = null;
        MicroSecondDate twoYearsAgo = new MicroSecondDate().subtract(new TimeInterval(2, UnitImpl.GREGORIAN_YEAR));
        for(int i = 0; i < nets.length; i++) {
            System.out.println(NetworkIdUtil.toStringNoDates(nets[i].get_attributes()));
            if (NetworkIdUtil.toStringNoDates(nets[i].get_attributes().get_id()).endsWith("10")) {
                net = nets[i];
            }
        }
        Station[] stations = net.retrieve_stations();
        int s=0;
        for(s = 0; s < stations.length; s++) {
            System.out.println("Station: "+stations[s].get_code());
            if (stations[s].get_code().equals("U02B")) {
               break; 
            }
        }
        
        Channel[] channels = net.retrieve_for_station(stations[s].get_id());
        int j=0;
        for(j = 0; j < channels.length; j++) {
            if (channels[j].get_code().equals("HHE")) {
                break;
            }
        }
        DataCenter seisDC = namingService.getSeismogramDC("edu/sc/seis/test",
                                                          "thirdFloor");
        RequestFilter[] seismogramRequest = new RequestFilter[1];
        Time start = new Time("2011-01-04T16:23:25.0000Z", -1);
        Time end = new Time("2011-01-04T16:43:25.0000Z", -1);
     //   seismogramRequest[0] = new RequestFilter(channels[j].get_id(),
     //                                            start,
     //                                            end);
        seismogramRequest[0] = new RequestFilter(new ChannelId(new NetworkId("*", channels[j].get_id().network_id.begin_time),
                                                               channels[j].get_id().station_code,
                                                               channels[j].get_id().site_code,
                                                               channels[j].get_id().channel_code,
                                                               channels[j].get_id().begin_time),
                                                 start,
                                                 end);
        logger.info("querying for "+seismogramRequest[0].channel_id.network_id.network_code+"."
                    +seismogramRequest[0].channel_id.station_code+"."
                    +seismogramRequest[0].channel_id.site_code+"."
                    +seismogramRequest[0].channel_id.channel_code);
        try {
            
        
        LocalSeismogram[] seis = seisDC.retrieve_seismograms(seismogramRequest);
        logger.info("received "+seis.length+" seismograms");
        for(int i = 0; i < seis.length; i++) {
            logger.info("seis[" + i + "] has " + seis[i].num_points
                    + " points and starts at " + seis[i].begin_time.date_time);
        }
        }catch(Throwable t) {
            logger.error("problem: ", t);
        }
    }

    private static final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(Client.class);
}
